@@ -1,13 +1,13 @@
 package Archive::BagIt::Plugin::Algorithm::SHA512;
 use strict;
 use warnings;
-use Carp;
+use Carp qw( croak );
 use Moo;
-use Net::SSLeay;
+use Net::SSLeay ();
 use namespace::autoclean;
 with 'Archive::BagIt::Role::Algorithm';
 # ABSTRACT: The default SHA algorithms plugin (default for v1.0)
-our $VERSION = '0.074'; # VERSION
+our $VERSION = '0.075'; # VERSION
 
 sub BEGIN {
     Net::SSLeay::OpenSSL_add_all_digests();
@@ -75,7 +75,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin (d
 
 =head1 VERSION
 
-version 0.074
+version 0.075
 
 =head1 AVAILABILITY
 
